@@ -1,10 +1,8 @@
-"guiMode" <-
-function()
+guiMode <- function()
 {
-  #requireNamespace(tcltk)
-  backupScipen <- options(scipen=10)[[1]]
+  pkg.env$taskWindow <- tcltk::tktoplevel()
+  taskWindow <- pkg.env$taskWindow
 
-  taskWindow<-tktoplevel()
   tkwm.title(taskWindow,"Choose a Task")
   listBoxTasks<-tklistbox(taskWindow,height=4,width=40,selectmode="single",background="white")
   tkgrid(tklabel(taskWindow,text="Select a Task!"))
@@ -32,16 +30,6 @@ function()
     }
   }
 
-  quitGroupSeq <- function()
-  {
-   tkdestroy(taskWindow)
-
-   # restore scipen value
-   options(scipen=backupScipen)
-   cat("GroupSeq closed by user.\n\n")
-   return()
-  }
-
   OK.button <-tkbutton(taskWindow,text="   Perform Selected Task   ",command=OnOKtaskWindow)
   Quit.buttton <- tkbutton(taskWindow,text="  QUIT GroupSeq  ",command=quitGroupSeq)
 
